==> v0.6.0.tar.gz: argos/dmp-frontend/src/app/ui/misc/dataset-description-form/dataset-description-form.module.ts <==
import { NgModule } from '@angular/core';
import { AutoCompleteModule } from '@app/library/auto-complete/auto-complete.module';
import { FormCompositeFieldComponent } from '@app/ui/misc/dataset-description-form/components/form-composite-field/form-composite-field.component';
import { FormFieldComponent } from '@app/ui/misc/dataset-description-form/components/form-field/form-field.component';
import { FormProgressIndicationComponent } from '@app/ui/misc/dataset-description-form/components/form-progress-indication/form-progress-indication.component';
import { FormSectionComponent } from '@app/ui/misc/dataset-description-form/components/form-section/form-section.component';
import { DatasetDescriptionFormComponent } from '@app/ui/misc/dataset-description-form/dataset-description-form.component';
import { FormFocusService } from '@app/ui/misc/dataset-description-form/form-focus/form-focus.service';
import { VisibilityRulesService } from '@app/ui/misc/dataset-description-form/visibility-rules/visibility-rules.service';
import { CommonFormsModule } from '@common/forms/common-forms.module';
import { CommonUiModule } from '@common/ui/common-ui.module';
import { FormCompositeTitleComponent } from './components/form-composite-title/form-composite-title.component';
import { ExternalSourcesModule } from '../external-sources/external-sources.module';

@NgModule({
	imports: [
		CommonUiModule,
		CommonFormsModule,
		AutoCompleteModule,
		ExternalSourcesModule
	],
	declarations: [
		DatasetDescriptionFormComponent,
		FormProgressIndicationComponent,
		FormSectionComponent,
		FormCompositeFieldComponent,
		FormFieldComponent,
		FormCompositeTitleComponent
	],
	exports: [
		DatasetDescriptionFormComponent
	],
	providers: [
		VisibilityRulesService,
		FormFocusService
	]
})
export class DatasetDescriptionFormModule { }

==> v0.7.1.tar.gz: argos/dmp-frontend/src/app/ui/misc/dataset-description-form/dataset-description-form.module.ts <==
import { NgModule } from '@angular/core';
import { AutoCompleteModule } from '@app/library/auto-complete/auto-complete.module';
import { FormCompositeFieldComponent } from '@app/ui/misc/dataset-description-form/components/form-composite-field/form-composite-field.component';
import { FormFieldComponent } from '@app/ui/misc/dataset-description-form/components/form-field/form-field.component';
import { FormProgressIndicationComponent } from '@app/ui/misc/dataset-description-form/components/form-progress-indication/form-progress-indication.component';
import { FormSectionComponent } from '@app/ui/misc/dataset-description-form/components/form-section/form-section.component';
import { DatasetDescriptionFormComponent } from '@app/ui/misc/dataset-description-form/dataset-description-form.component';
import { FormFocusService } from '@app/ui/misc/dataset-description-form/form-focus/form-focus.service';
import { VisibilityRulesService } from '@app/ui/misc/dataset-description-form/visibility-rules/visibility-rules.service';
import { CommonFormsModule } from '@common/forms/common-forms.module';
import { CommonUiModule } from '@common/ui/common-ui.module';
import { FormCompositeTitleComponent } from './components/form-composite-title/form-composite-title.component';
import { ExternalSourcesModule } from '../external-sources/external-sources.module';
import { DatasetDescriptionComponent } from './dataset-description.component';

@NgModule({
	imports: [
		CommonUiModule,
		CommonFormsModule,
		AutoCompleteModule,
		ExternalSourcesModule
	],
	declarations: [
		DatasetDescriptionFormComponent,
		DatasetDescriptionComponent,
		FormProgressIndicationComponent,
		FormSectionComponent,
		FormCompositeFieldComponent,
		FormFieldComponent,
		FormCompositeTitleComponent
	],
	exports: [
		DatasetDescriptionFormComponent,
		DatasetDescriptionComponent
	],
	providers: [
		VisibilityRulesService,
		FormFocusService
	]
})
export class DatasetDescriptionFormModule { }
